@@ -42,10 +42,10 @@ bool Control::SetModel(Lum::Base::Model* model)
 void Control::CalcSize()
 {
   if (Lum::OS::display->GetSize()<=Lum::OS::Display::sizeSmall) {
-    cellSize=Lum::OS::display->GetFont(Lum::OS::Display::fontTypeProportional)->height/2;
+    cellSize=Lum::OS::display->GetFont()->height/2;
   }
   else {
-    cellSize=Lum::OS::display->GetFont(Lum::OS::Display::fontTypeProportional)->height;
+    cellSize=Lum::OS::display->GetFont()->height;
   }
 
   minWidth=(GameArea::dimension+1)*1+GameArea::dimension*cellSize;
@@ -79,16 +79,6 @@ void Control::Draw(int x, int y, size_t w, size_t h)
 
   draw->PushForeground(lineColor);
 
-  if (width>cellSize*GameArea::dimension+GameArea::dimension+1) {
-    DrawParentBackground(this->x+cellSize*GameArea::dimension+GameArea::dimension+1,this->y,
-                         width-(cellSize*GameArea::dimension+GameArea::dimension+1),height);
-  }
-
-  if (height>cellSize*GameArea::dimension+GameArea::dimension+1) {
-    DrawParentBackground(this->x,this->y+cellSize*GameArea::dimension+GameArea::dimension+1,
-                         width,height-(cellSize*GameArea::dimension+GameArea::dimension+1));
-  }
-
   // Vertical lines
   offset=0;
   for (size_t i=0; i<=GameArea::dimension; i++) {
